@@ -66,7 +66,7 @@ my @method_names =qw(
     array_max array_overflow array_preserve hash_max hash_overflow
     hash_preserve ignore_keys unicode_charnames colored theme show_weak
     max_depth index separator end_separator class_method class hash_separator
-    align_hash sort_keys quote_keys deparse return_value show_dualvar
+    align_hash sort_keys quote_keys deparse return_value show_dualvar show_tied
 );
 foreach my $method_name (@method_names) {
     no strict 'refs';
@@ -114,6 +114,7 @@ sub _init {
     $self->{'index'} = Data::Printer::Common::_fetch_scalar_or_default($props, 'index', 1);
     $self->{'name'} = Data::Printer::Common::_fetch_scalar_or_default($props, 'name', 'var');
     $self->{'show_tainted'} = Data::Printer::Common::_fetch_scalar_or_default($props, 'show_tainted', 1);
+    $self->{'show_tied'} = Data::Printer::Common::_fetch_scalar_or_default($props, 'show_tied', 1);
     $self->{'show_weak'} = Data::Printer::Common::_fetch_scalar_or_default($props, 'show_weak', 1);
     $self->{'show_unicode'} = Data::Printer::Common::_fetch_scalar_or_default($props, 'show_unicode', 0);
     $self->{'show_readonly'} = Data::Printer::Common::_fetch_scalar_or_default($props, 'show_readonly', 1);
@@ -537,6 +538,15 @@ sub _see {
     return $self->{_seen}{$id};
 }
 
+sub unsee {
+    my ($self, $data) = @_;
+    return unless ref $data && keys %{$self->{_seen}};
+
+    my $id = Data::Printer::Common::_object_id($data);
+    delete $self->{_seen}{$id};
+    return;
+}
+
 sub _refcount {
     my ($self, $data) = @_;
 
@@ -706,7 +716,6 @@ sub maybe_colorize {
     return $output;
 }
 
-
 sub _check_readonly {
     my ($self) = @_;
     return ' (read-only)' if $self->show_readonly && &Internals::SvREADONLY($_[1]);
@@ -785,7 +794,8 @@ reference instead of entenring an infinite loop. However, there are cases
 when you wanto to print the same data structure twice, like when you're doing
 a second pass on a blessed object to print its internals, or if you're using
 the same object over and over again. This setting overrides the internal
-counter and prints the same data again.
+counter and prints the same data again. Check L<usee|/unsee> below for another
+way to achieve this.
 
 =back
 
@@ -840,6 +850,13 @@ In the code above, if the user has C<colors.filter_myclass> set either on the
 C<.dataprinter> file or the runtime hashref, that one will be used. Otherwise,
 Data::Printer will use C<'#ffccb3'>.
 
+=head2 unsee( $data )
+
+Sometimes you are writing a filter for data that you know will be repeated
+several times, like JSON Boolean objects. To prevent Data::Printer from
+showing this content as repeated, you can use the C<unsee> method to make
+the current object forget about having ever visited this data.
+
 =head1 OTHER METHODS / PROPERTIES
 
 Most of them are described in L<Data::Printer>.
@@ -916,7 +933,7 @@ Most of them are described in L<Data::Printer>.
 
 =item * show_memsize - whether to show memory size of data structure. Requires Devel::Size (default: 0)
 
-=item * show_readonly - whether label readonly data (default: 1)
+=item * show_readonly - whether to label readonly data (default: 1)
 
 =item * show_refcount - whether to show data refcount it's above 1 (default: 0)
 
@@ -926,6 +943,8 @@ Most of them are described in L<Data::Printer>.
 
 =item * show_weak - whether to label weak references (default: 1)
 
+=item * show_tied - whether to label tied variables (default: 1)
+
 =item * sort_keys - whether to sort hash keys (default: 1)
 
 =item * string_max - maxumum number of characters in a string. Set to 0 to show all (default: 1024)
